==> vue-badge-2.8.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/badge/vue";
import { defineComponent, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var classes = {
  "primary-status": "inline-flex items-center justify-center leading-4 relative",
  "dot-showleft": "ml-2.5",
  "dot-showleft-child": "w-1.5 h-1.5 absolute -left-2.5 ml-0",
  "primary-status-child": "rounded-xl bg-color-error",
  "type-danger": "bg-color-error",
  "type-primary": "bg-color-brand",
  "type-success": "bg-color-success",
  "type-warning": "bg-color-alert",
  "type-default": "bg-color-error",
  "type-info": "bg-color-border",
  "type-icon": "h-1.5 self-start -ml-1.5 z-10",
  "circle": "min-w-[theme(spacing.4)] h-4 px-1 py-0 ml-1 text-color-bg-1 text-xs text-center box-border",
  "circle-icon-label": "box-border -ml-2 -mt-1.5",
  "dot-default-icon-label": "w-1.5 h-1.5 self-start z-10",
  "dot-default": "w-1.5 h-1.5 ml-1",
  "state-href": "!text-color-bg-1 !no-underline",
  "state-not-href": "inline-block align-top"
};
var __vue2_script = defineComponent({
  props: [].concat(props, ["showLeft", "isDot", "hidden", "type", "max", "value", "modelValue", "href", "target", "data"]),
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api,
      classes
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    class: _vm.m(_vm.gcls("primary-status"), _vm.gcls({
      "dot-showleft": _vm.isDot && _vm.showLeft
    })),
    attrs: {
      "data-tag": "tiny-badge"
    }
  }, [_vm.data ? _c("span", [_vm._v(_vm._s(_vm.data))]) : _vm._t("default"), !_vm.hidden && (_vm.state.content || _vm.state.content === 0 || _vm.isDot || _vm.showLeft) ? _c("div", {
    class: _vm.m(_vm.gcls("primary-status-child"), _vm.gcls({
      "dot-showleft-child": _vm.showLeft && _vm.isDot
    }), _vm.gcls("type-" + (_vm.type || "default")), _vm.gcls({
      "circle": !_vm.isDot
    }), _vm.gcls({
      "dot-default-icon-label": !_vm.showLeft && _vm.isDot && ["icon", "label"].includes(_vm.type)
    }), _vm.gcls({
      "dot-default": !_vm.showLeft && _vm.isDot && !["icon", "label"].includes(_vm.type)
    }), _vm.gcls({
      "circle-icon-label": !_vm.isDot && ["icon", "label"].includes(_vm.type)
    })),
    attrs: {
      "data-tag": "tiny-badge-content"
    }
  }, [_vm._t("content", function() {
    return [_vm.state.href ? _c("a", {
      class: _vm.m(_vm.gcls("state-href")),
      attrs: {
        "href": _vm.state.href,
        "target": _vm.target,
        "rel": "noopener noreferrer"
      }
    }, [_vm._v(_vm._s(_vm.state.content))]) : _c("span", {
      class: _vm.m(_vm.gcls("state-not-href"))
    }, [_vm._v(_vm._s(_vm.state.content))])];
  })], 2) : _vm._e()], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  mobileFirst as default
};

==> vue-badge-2.21.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/badge/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var classes = {
  "primary-status": "inline-flex items-center justify-center leading-4 relative",
  "dot-showleft": "ml-2.5",
  "dot-showleft-child": "w-1.5 h-1.5 absolute -left-2.5 ml-0",
  "primary-status-child": "rounded-xl bg-color-error",
  "type-danger": "bg-color-error",
  "type-primary": "bg-color-brand",
  "type-success": "bg-color-success",
  "type-warning": "bg-color-alert",
  "type-default": "bg-color-error",
  "type-info": "bg-color-border",
  "type-icon": "h-1.5 self-start -ml-1.5 z-10",
  "circle": "min-w-[theme(spacing.4)] h-4 px-1 py-0 ml-1 text-color-bg-1 text-xs text-center box-border",
  "circle-icon-label": "box-border -ml-2 -mt-1.5",
  "dot-default-icon-label": "w-1.5 h-1.5 self-start z-10",
  "dot-default": "w-1.5 h-1.5 ml-1",
  "state-href": "!text-color-bg-1 !no-underline",
  "state-not-href": "inline-block align-top"
};
var __vue2_script = defineComponent({
  props: [].concat(props, ["showLeft", "isDot", "hidden", "type", "max", "value", "modelValue", "href", "target", "data"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      classes
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    class: _vm.m(_vm.gcls("primary-status"), _vm.gcls({
      "dot-showleft": _vm.isDot && _vm.showLeft
    })),
    attrs: {
      "data-tag": "tiny-badge"
    }
  }, [_vm.data ? _c("span", [_vm._v(_vm._s(_vm.data))]) : _vm._t("default"), !_vm.hidden && (_vm.state.content || _vm.state.content === 0 || _vm.isDot || _vm.showLeft) ? _c("div", {
    class: _vm.m(_vm.gcls("primary-status-child"), _vm.gcls({
      "dot-showleft-child": _vm.showLeft && _vm.isDot
    }), _vm.gcls("type-" + (_vm.type || "default")), _vm.gcls({
      "circle": !_vm.isDot
    }), _vm.gcls({
      "dot-default-icon-label": !_vm.showLeft && _vm.isDot && ["icon", "label"].includes(_vm.type)
    }), _vm.gcls({
      "dot-default": !_vm.showLeft && _vm.isDot && !["icon", "label"].includes(_vm.type)
    }), _vm.gcls({
      "circle-icon-label": !_vm.isDot && ["icon", "label"].includes(_vm.type)
    })),
    attrs: {
      "data-tag": "tiny-badge-content"
    }
  }, [_vm._t("content", function() {
    return [_vm.state.href ? _c("a", {
      class: _vm.m(_vm.gcls("state-href")),
      attrs: {
        "href": _vm.state.href,
        "target": _vm.target,
        "rel": "noopener noreferrer"
      }
    }, [_vm._v(_vm._s(_vm.state.content))]) : _c("span", {
      class: _vm.m(_vm.gcls("state-not-href"))
    }, [_vm._v(_vm._s(_vm.state.content))])];
  })], 2) : _vm._e()], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
